@@ -36,6 +36,7 @@ from making_with_code_cli.cli_setup import (
     InstallGit,
     InstallTree,
     InstallAtom,
+    InstallImageMagick,
     GHAuthentication,
 )
 from making_with_code_cli.curriculum import (
@@ -67,13 +68,16 @@ def setup(ctx, yes, teacher):
     for note in INTRO_NOTES:
         click.echo(address(note, list_format=True))
     click.echo()
-    #settings['mwc_username'] = choose_mwc_username(settings.get("mwc_username"))
+    settings['mwc_username'] = choose_mwc_username(settings.get("mwc_username"))
     settings['role'] = "teacher" if teacher else "student"
     settings['work_dir'] = str(choose_work_dir(settings.get("work_dir")).resolve())
     settings['mwc_site_url'] = choose_mwc_site_url(settings.get('mwc_site_url'))
     curriculum = get_curriculum(settings)
     settings['course'] = choose_course([course['name'] for course in curriculum['courses']])
+    course = [c for c in curriculum['courses'] if c['name'] == settings['course']][0]
     settings['editor'] = choose_editor(settings.get('editor', 'atom'))
+    G = get_backend(course['git_backend'])
+    settings = G.extend_settings(settings)
     if yes:
         click.echo(info("Updated settings:"))
         click.echo(info(yaml.dump(settings), preformatted=True))
@@ -95,6 +99,7 @@ def setup(ctx, yes, teacher):
         InstallGit(settings),
         InstallTree(settings),
         InstallAtom(settings),
+        InstallImageMagick(settings),
         GHAuthentication(settings),
     ]
     for task in tasks:
